#
# spec file for package supercollider-sc3-plugins
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define build_supernova 1
# what extra options to compile with
%define cmakearch -DSSE=OFF
%ifarch x86_64
%define cmakearch -DSSE=ON -DX86_64=ON
%endif
%ifarch %{ix86}
%define cmakearch -DSSE=ON -DI686=ON
%endif
# options to build supernova
%if 0%{?build_supernova}
%define cmakesupernova -DSUPERNOVA=ON
%else
%define cmakesupernova -DSUPERNOVA=OFF
%endif
Name:           supercollider-sc3-plugins
Version:        3.13.0
Release:        2.5
Summary:        Collection of SuperCollider plugins
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://supercollider.github.io/sc3-plugins/
Source0:        https://github.com/supercollider/sc3-plugins/releases/download/Version-%{version}/sc3-plugins-%{version}-Source.tar.bz2
Source1:        https://github.com/supercollider/sc3-plugins/releases/download/Version-%{version}/sc3-plugins-%{version}-Source.tar.bz2.asc
Source9:        supercollider-sc3-plugins.keyring
Source99:       supercollider-sc3-plugins-rpmlintrc
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  fftw-devel
BuildRequires:  gcc-c++
BuildRequires:  supercollider-devel
Requires:       supercollider >= 3.5

%description
Collection of free and usefull SuperCollider plugins

%prep
%setup -q -n sc3-plugins-%{version}-Source

%build
%ifarch ppc ppc64 ppc64le
export CFLAGS='%{optflags} -mno-altivec'
export CXXFLAGS='%{optflags} -mno-altivec'
%endif
%cmake \
	-DSC_PATH=%{_includedir}/SuperCollider \
	%{cmakearch} \
	%{?cmakesupernova}
%make_build clean
%make_build

%install
cd build
%make_install
%fdupes %{buildroot}%{_prefix}

%files
%license license.txt
%doc README.md
%dir %{_datadir}/SuperCollider
%dir %{_datadir}/SuperCollider/Extensions
%dir %{_datadir}/SuperCollider/Extensions/SC3plugins
%{_datadir}/SuperCollider/Extensions/SC3plugins
%dir %{_libdir}/SuperCollider
%dir %{_libdir}/SuperCollider/plugins
%{_libdir}/SuperCollider/plugins

%changelog
* Tue Aug  1 2023 Konstantin Voinov <kv@kott.no-ip.biz>
- Disable QUARKS=ON as it gives no effect and installs plugins in
  to wrong path (boo#1213615).
* Mon Feb 27 2023 Dirk Müller <dmueller@suse.com>
- update to 3.13.0:
  * We are pleased to share the 3.13.0 release of sc3-plugins!
  * This version is compatible with SuperCollider 3.13.x, 3.12.x,
    and possibly a couple of earlier releases.
  * ATK: fix speed of sound
  * Documentation updates
  * Add option to turn off LADSPA plugins, which cause scsynth to
    segfault on some Linux systems (#260)
  * Documentation improvements (#298, #299)
- add license and README
* Tue Mar  8 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- A note that all patches from 3.6 where removed:
  stk not needed anymore
  other things seems to be fixed in upstream
* Tue Mar  8 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- toggle services off
* Tue Mar  8 2022 kv@kott.no-ip.biz
- Update to version 3.11.1+git.48.4416f95:
  * Bump nokogiri from 1.12.5 to 1.13.3
  * GHA: run on **.txt file changes
  * CMakeLists: fix LIB_SUFFIX
  * cmake:lib_suffix Fix indentation. Add note in README.md.
  * Add option for LIB_SUFFIX
  * gha CI: ignore changes to the webstie
  * Bump nokogiri from 1.11.7 to 1.12.5
  * ATK refactor: speed of sound, maintain backwards compatability
  * Dfsm: remove flag, too
  * Dfsm: don't need to ever post, remove flag
  * Dfsm shouldn't always post
  * gha: add ccache for linux
  * gha: move cmake flags to the matrix
  * gha: rename windows builds
  * gha: correct macos env variables
  * ATK refactor: add user settable speed of sound
  * update: ATK README sc3-plugins v3.12.0
  * ATK fix: FoaProximity, FoaNFC conform FOA speed of sound to HOA
* Wed Sep  1 2021 kv@kott.no-ip.biz
- Update to version 3.12.0+git0.dca5c0b:
  * gha: specify xcode and deployment target for macOS
  * Remove Travis
  * Remove AppVeyor
  * add github actions CI
  * CMake: add search paths for finding FFTW on Windows
  * website: update jekyll etc
  * website: update cayman theme source
  * Bump addressable from 2.5.2 to 2.8.0
  * Bump nokogiri from 1.10.8 to 1.11.4
  * docs: if you don't want SUPERNOVA you actually have to explicitly disable it
* Sat Oct 31 2015 rpm@fthiessen.de
- Fixed build:
  * Added fix-ldl.patch (missing libdl)
  * Added fix-returns-random-data.patch for rpmlint errors
  * Added fdupes in spec file
* Wed Sep 16 2015 prusnak@opensuse.org
- update to latest git for 3.7.0 alpha1
* Mon Oct 27 2014 prusnak@opensuse.org
- created package
- based on Fedora CCRMA package by Fernando Lopez-Lezcano
